@@ -839,9 +839,14 @@ winBltExposedWindowRegionShadowGDI(ScreenPtr pScreen, WindowPtr pWin)
         /* Get the window bitmap from the pixmap */
         hBitmap = pPixmapPriv->hBitmap;
 
-        /* XXX: There may be a need for a slow-path here: If hBitmap is NULL, we
-           should fall-back to creating a Windows DIB from the pixmap, then
-           deleting it after the BitBlt. */
+        /* XXX: There may be a need for a slow-path here: If hBitmap is NULL
+           (because we couldn't back the pixmap with a Windows DIB), we should
+           fall-back to creating a Windows DIB from the pixmap, then deleting it
+           after the BitBlt (as this this code did before the fast-path was
+           added). */
+        if (!hBitmap) {
+            ErrorF("winBltExposedWindowRegionShadowGDI - slow path unimplemented\n");
+        }
 
         /* Select the window bitmap into a screen-compatible DC */
         hdcPixmap = CreateCompatibleDC(pScreenPriv->hdcScreen);
@@ -866,7 +871,6 @@ winBltExposedWindowRegionShadowGDI(ScreenPtr pScreen, WindowPtr pWin)
 #endif
     {
     /* Try to copy from the shadow buffer to the invalidated region */
-    /* XXX: looks like those coordinates should get transformed ??? */
     if (!BitBlt(hdcUpdate,
                 ps.rcPaint.left, ps.rcPaint.top,
                 ps.rcPaint.right - ps.rcPaint.left,
@@ -1241,7 +1245,7 @@ winDestroyColormapShadowGDI(ColormapPtr pColormap)
 }
 
 /*
- * Set engine specific funtions
+ * Set engine specific functions
  */
 
 Bool
